# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DecribeCollectionData:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'store_name': 'str',
        'collection_name': 'str',
        'fields': 'list[FieldData]',
        'load_state': 'str',
        'description': 'str',
        'params': 'dict(str, object)',
        'indexes': 'list[IndexParams]',
        'entity_num': 'int'
    }

    attribute_map = {
        'store_name': 'store_name',
        'collection_name': 'collection_name',
        'fields': 'fields',
        'load_state': 'load_state',
        'description': 'description',
        'params': 'params',
        'indexes': 'indexes',
        'entity_num': 'entity_num'
    }

    def __init__(self, store_name=None, collection_name=None, fields=None, load_state=None, description=None, params=None, indexes=None, entity_num=None):
        r"""DecribeCollectionData

        The model defined in huaweicloud sdk

        :param store_name: **参数解释：** 知识仓实例名称，region内唯一。 **约束限制：** 长度范围为3到63个字符，支持小写字母、数字、中划线（-），第一个字符只能够是小写字母，中划线(-)不得出现在字符串末尾。 **取值范围：** 不涉及。 **默认取值：** 不涉及。
        :type store_name: str
        :param collection_name: **参数解释：** collection名称。 **约束限制：** 可包含数字、字母和下划线 (_)。资源名称必须以字母或下划线 (_) 开头。最大长度支持255。 **取值范围：** 不涉及。 **默认取值:** 不涉及。
        :type collection_name: str
        :param fields: **参数解释：** collection各个field信息。 **约束限制：** 不涉及。
        :type fields: list[:class:`huaweicloudsdkdwr.v1.FieldData`]
        :param load_state: **参数解释：** 标识当前Collection加载状态。 **约束限制：** 不涉及。 **取值范围：** 1、LoadStateLoaded：表示当前Collection已准备就绪，可正常使用。 2、LoadStateLoading：表示当前Collection正在load。 3、LoadStateNotLoad：表示collection未加载。 **默认取值:** 不涉及。
        :type load_state: str
        :param description: **参数解释：** Collection 的描述信息。 **约束限制：** 不涉及。 **取值范围：** 不涉及。 **默认取值:** 不涉及。
        :type description: str
        :param params: **参数解释：** collection常用参数。 **约束限制：** shards_num: 默认2，取值范围[1, 16] partitions_num: 默认4，取值范围[1, 1024]，若所有field的partition_key为false，则partitions_num固定为1。 max_length: 默认256，取值范围[1, 65535]，当primary_field.type为String时，指示String的最大长度。
        :type params: dict(str, object)
        :param indexes: **参数解释：** 索引的配置信息。 **约束限制：** 不涉及。
        :type indexes: list[:class:`huaweicloudsdkdwr.v1.IndexParams`]
        :param entity_num: **参数解释：** collection中的entity数量。 **约束限制：** 不涉及。 **取值范围：** 不涉及。 **默认取值:** 不涉及。
        :type entity_num: int
        """
        
        

        self._store_name = None
        self._collection_name = None
        self._fields = None
        self._load_state = None
        self._description = None
        self._params = None
        self._indexes = None
        self._entity_num = None
        self.discriminator = None

        self.store_name = store_name
        self.collection_name = collection_name
        self.fields = fields
        if load_state is not None:
            self.load_state = load_state
        if description is not None:
            self.description = description
        if params is not None:
            self.params = params
        if indexes is not None:
            self.indexes = indexes
        if entity_num is not None:
            self.entity_num = entity_num

    @property
    def store_name(self):
        r"""Gets the store_name of this DecribeCollectionData.

        **参数解释：** 知识仓实例名称，region内唯一。 **约束限制：** 长度范围为3到63个字符，支持小写字母、数字、中划线（-），第一个字符只能够是小写字母，中划线(-)不得出现在字符串末尾。 **取值范围：** 不涉及。 **默认取值：** 不涉及。

        :return: The store_name of this DecribeCollectionData.
        :rtype: str
        """
        return self._store_name

    @store_name.setter
    def store_name(self, store_name):
        r"""Sets the store_name of this DecribeCollectionData.

        **参数解释：** 知识仓实例名称，region内唯一。 **约束限制：** 长度范围为3到63个字符，支持小写字母、数字、中划线（-），第一个字符只能够是小写字母，中划线(-)不得出现在字符串末尾。 **取值范围：** 不涉及。 **默认取值：** 不涉及。

        :param store_name: The store_name of this DecribeCollectionData.
        :type store_name: str
        """
        self._store_name = store_name

    @property
    def collection_name(self):
        r"""Gets the collection_name of this DecribeCollectionData.

        **参数解释：** collection名称。 **约束限制：** 可包含数字、字母和下划线 (_)。资源名称必须以字母或下划线 (_) 开头。最大长度支持255。 **取值范围：** 不涉及。 **默认取值:** 不涉及。

        :return: The collection_name of this DecribeCollectionData.
        :rtype: str
        """
        return self._collection_name

    @collection_name.setter
    def collection_name(self, collection_name):
        r"""Sets the collection_name of this DecribeCollectionData.

        **参数解释：** collection名称。 **约束限制：** 可包含数字、字母和下划线 (_)。资源名称必须以字母或下划线 (_) 开头。最大长度支持255。 **取值范围：** 不涉及。 **默认取值:** 不涉及。

        :param collection_name: The collection_name of this DecribeCollectionData.
        :type collection_name: str
        """
        self._collection_name = collection_name

    @property
    def fields(self):
        r"""Gets the fields of this DecribeCollectionData.

        **参数解释：** collection各个field信息。 **约束限制：** 不涉及。

        :return: The fields of this DecribeCollectionData.
        :rtype: list[:class:`huaweicloudsdkdwr.v1.FieldData`]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        r"""Sets the fields of this DecribeCollectionData.

        **参数解释：** collection各个field信息。 **约束限制：** 不涉及。

        :param fields: The fields of this DecribeCollectionData.
        :type fields: list[:class:`huaweicloudsdkdwr.v1.FieldData`]
        """
        self._fields = fields

    @property
    def load_state(self):
        r"""Gets the load_state of this DecribeCollectionData.

        **参数解释：** 标识当前Collection加载状态。 **约束限制：** 不涉及。 **取值范围：** 1、LoadStateLoaded：表示当前Collection已准备就绪，可正常使用。 2、LoadStateLoading：表示当前Collection正在load。 3、LoadStateNotLoad：表示collection未加载。 **默认取值:** 不涉及。

        :return: The load_state of this DecribeCollectionData.
        :rtype: str
        """
        return self._load_state

    @load_state.setter
    def load_state(self, load_state):
        r"""Sets the load_state of this DecribeCollectionData.

        **参数解释：** 标识当前Collection加载状态。 **约束限制：** 不涉及。 **取值范围：** 1、LoadStateLoaded：表示当前Collection已准备就绪，可正常使用。 2、LoadStateLoading：表示当前Collection正在load。 3、LoadStateNotLoad：表示collection未加载。 **默认取值:** 不涉及。

        :param load_state: The load_state of this DecribeCollectionData.
        :type load_state: str
        """
        self._load_state = load_state

    @property
    def description(self):
        r"""Gets the description of this DecribeCollectionData.

        **参数解释：** Collection 的描述信息。 **约束限制：** 不涉及。 **取值范围：** 不涉及。 **默认取值:** 不涉及。

        :return: The description of this DecribeCollectionData.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        r"""Sets the description of this DecribeCollectionData.

        **参数解释：** Collection 的描述信息。 **约束限制：** 不涉及。 **取值范围：** 不涉及。 **默认取值:** 不涉及。

        :param description: The description of this DecribeCollectionData.
        :type description: str
        """
        self._description = description

    @property
    def params(self):
        r"""Gets the params of this DecribeCollectionData.

        **参数解释：** collection常用参数。 **约束限制：** shards_num: 默认2，取值范围[1, 16] partitions_num: 默认4，取值范围[1, 1024]，若所有field的partition_key为false，则partitions_num固定为1。 max_length: 默认256，取值范围[1, 65535]，当primary_field.type为String时，指示String的最大长度。

        :return: The params of this DecribeCollectionData.
        :rtype: dict(str, object)
        """
        return self._params

    @params.setter
    def params(self, params):
        r"""Sets the params of this DecribeCollectionData.

        **参数解释：** collection常用参数。 **约束限制：** shards_num: 默认2，取值范围[1, 16] partitions_num: 默认4，取值范围[1, 1024]，若所有field的partition_key为false，则partitions_num固定为1。 max_length: 默认256，取值范围[1, 65535]，当primary_field.type为String时，指示String的最大长度。

        :param params: The params of this DecribeCollectionData.
        :type params: dict(str, object)
        """
        self._params = params

    @property
    def indexes(self):
        r"""Gets the indexes of this DecribeCollectionData.

        **参数解释：** 索引的配置信息。 **约束限制：** 不涉及。

        :return: The indexes of this DecribeCollectionData.
        :rtype: list[:class:`huaweicloudsdkdwr.v1.IndexParams`]
        """
        return self._indexes

    @indexes.setter
    def indexes(self, indexes):
        r"""Sets the indexes of this DecribeCollectionData.

        **参数解释：** 索引的配置信息。 **约束限制：** 不涉及。

        :param indexes: The indexes of this DecribeCollectionData.
        :type indexes: list[:class:`huaweicloudsdkdwr.v1.IndexParams`]
        """
        self._indexes = indexes

    @property
    def entity_num(self):
        r"""Gets the entity_num of this DecribeCollectionData.

        **参数解释：** collection中的entity数量。 **约束限制：** 不涉及。 **取值范围：** 不涉及。 **默认取值:** 不涉及。

        :return: The entity_num of this DecribeCollectionData.
        :rtype: int
        """
        return self._entity_num

    @entity_num.setter
    def entity_num(self, entity_num):
        r"""Sets the entity_num of this DecribeCollectionData.

        **参数解释：** collection中的entity数量。 **约束限制：** 不涉及。 **取值范围：** 不涉及。 **默认取值:** 不涉及。

        :param entity_num: The entity_num of this DecribeCollectionData.
        :type entity_num: int
        """
        self._entity_num = entity_num

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DecribeCollectionData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
